==> isddc-1.0.0.tar.gz: isddc-1.0.0/isddc/isddc_log.py <==
import logging
from logging import Logger

from . import ios
from . import idict
from . import isddc_decorator as idec


@idec.Retry('InitLog', cycle=10)
def __init__(name: str, conf: idict):
    return IsddcLog(name, conf)()


class IsddcLog:
    default_log_dir: str = ios.abspath(ios.dirname(__file__, 2), 'log')

    def __init__(self, name: str, conf: idict):
        self.name = name

        self.level: str = conf.level
        self.output: str = conf.output
        self.handler: str or list = conf.handler

        self.log = logging.getLogger(self.name)
        self.formatter = logging.Formatter(conf.logfmt, conf.datefmt)

        self.log.setLevel(self.level)

    def __call__(self) -> logging.getLogger:
        if self.output in ['file', 'both']:
            if isinstance(self.handler, list):
                for handler in self.handler:
                    self.add_file_handler(handler)
            else:
                self.add_file_handler(self.handler)

        if self.output in ['stream', 'both']:
            self.add_stream_handler()

        return self.log

    def add_file_handler(self, handler: str):
        if ios.isabs(handler):
            ios.genpath(ios.dirname(handler))
        else:
            handler = ios.abspath(self.default_log_dir, handler)

        handler = logging.FileHandler(handler, encoding='UTF-8')
        handler.setFormatter(self.formatter)
        self.log.addHandler(handler)

    def add_stream_handler(self):
        handler = logging.StreamHandler()
        handler.setFormatter(self.formatter)
        self.log.addHandler(handler)

    def logger_call(self, info, l: str = 'info'):
        getattr(self, l)(info)

    Logger.__call__ = logger_call


sine: logging.getLogger
simple: logging.getLogger

==> isddc-1.1.0.tar.gz: isddc-1.1.0/isddc/isddc_log.py <==
import logging
from logging import Logger

from . import ios
from . import idict
from . import isddc_decorator as idec


@idec.Retry('InitLog', cycle=10)
def __init__(name: str, conf: idict, **kw):
    return IsddcLog(name, conf, kw['basedir'])()


class IsddcLog:

    def __init__(self, name: str, conf: idict, basedir: str):
        self.name = name
        self.basedir = basedir

        self.level: str = conf.level
        self.output: str = conf.output
        self.handler: str or list = conf.handler

        self.log = logging.getLogger(self.name)
        self.formatter = logging.Formatter(conf.logfmt, conf.datefmt)

        self.log.setLevel(self.level)

    def __call__(self) -> logging.getLogger:
        if self.output in ['file', 'both']:
            if isinstance(self.handler, list):
                for handler in self.handler:
                    self.add_file_handler(handler)
            else:
                self.add_file_handler(self.handler)

        if self.output in ['stream', 'both']:
            self.add_stream_handler()

        return self.log

    def add_file_handler(self, handler: str):
        if ios.isabs(handler):
            ios.genpath(ios.dirname(handler))
        else:
            handler = ios.abspath(self.basedir, handler)

        handler = logging.FileHandler(handler, encoding='UTF-8')
        handler.setFormatter(self.formatter)
        self.log.addHandler(handler)

    def add_stream_handler(self):
        handler = logging.StreamHandler()
        handler.setFormatter(self.formatter)
        self.log.addHandler(handler)

    def logger_call(self, info, l: str = 'info'):
        getattr(self, l)(info)

    Logger.__call__ = logger_call


sine: logging.getLogger
simple: logging.getLogger
